@@ -31,20 +31,33 @@
 #include "fileicon.h"
 #include "fileinfo.h"
 #include "fileinputstream.h"
+#include "fileiostream.h"
 #include "filemonitor.h"
 #include "filenamecompleter.h"
 #include "fileoutputstream.h"
 #include "filterinputstream.h"
 #include "filteroutputstream.h"
 #include "icon.h"
+#include "inetaddress.h"
+#include "inetsocketaddress.h"
+#include "initable.h"
 #include "inputstream.h"
+#include "iostream.h"
 #include "loadableicon.h"
 #include "memoryinputstream.h"
 #include "memoryoutputstream.h"
 #include "mount.h"
 #include "mountoperation.h"
+#include "networkaddress.h"
+#include "networkservice.h"
 #include "outputstream.h"
+#include "resolver.h"
 #include "seekable.h"
+#include "socket.h"
+#include "socketaddress.h"
+#include "socketaddressenumerator.h"
+#include "socketconnectable.h"
+#include "srvtarget.h"
 #include "themedicon.h"
 #include "volume.h"
 #include "volumemonitor.h"
@@ -69,6 +82,7 @@ GType g_desktop_app_info_get_type(void);
 GType g_emblem_get_type(void);
 GType g_emblemed_icon_get_type(void);
 GType g_file_enumerator_get_type(void);
+GType g_file_io_stream_get_type(void);
 GType g_file_icon_get_type(void);
 GType g_file_info_get_type(void);
 GType g_file_input_stream_get_type(void);
@@ -77,11 +91,20 @@ GType g_file_output_stream_get_type(void);
 GType g_filename_completer_get_type(void);
 GType g_filter_input_stream_get_type(void);
 GType g_filter_output_stream_get_type(void);
+GType g_io_stream_get_type(void);
+GType g_inet_address_get_type(void);
+GType g_inet_socket_address_get_type(void);
 GType g_input_stream_get_type(void);
 GType g_memory_input_stream_get_type(void);
 GType g_memory_output_stream_get_type(void);
 GType g_mount_operation_get_type(void);
+GType g_network_address_get_type(void);
+GType g_network_service_get_type(void);
 GType g_output_stream_get_type(void);
+GType g_resolver_get_type(void);
+GType g_socket_get_type(void);
+GType g_socket_address_get_type(void);
+GType g_socket_address_enumerator_get_type(void);
 GType g_themed_icon_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_input_stream_get_type(void);
@@ -111,6 +134,7 @@ namespace Gio {  class DesktopAppInfo_Class { public: static Glib::ObjectBase* w
 namespace Gio {  class Emblem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class EmblemedIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class FileIOStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileInfo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -119,11 +143,20 @@ namespace Gio {  class FileOutputStream_Class { public: static Glib::ObjectBase*
 namespace Gio {  class FilenameCompleter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FilterInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FilterOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class IOStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class InetAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class InetSocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class InputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MemoryInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MemoryOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MountOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class NetworkAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class NetworkService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Resolver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketAddressEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class ThemedIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -153,6 +186,7 @@ void wrap_init()
   Glib::wrap_register(g_emblem_get_type(), &Gio::Emblem_Class::wrap_new);
   Glib::wrap_register(g_emblemed_icon_get_type(), &Gio::EmblemedIcon_Class::wrap_new);
   Glib::wrap_register(g_file_enumerator_get_type(), &Gio::FileEnumerator_Class::wrap_new);
+  Glib::wrap_register(g_file_io_stream_get_type(), &Gio::FileIOStream_Class::wrap_new);
   Glib::wrap_register(g_file_icon_get_type(), &Gio::FileIcon_Class::wrap_new);
   Glib::wrap_register(g_file_info_get_type(), &Gio::FileInfo_Class::wrap_new);
   Glib::wrap_register(g_file_input_stream_get_type(), &Gio::FileInputStream_Class::wrap_new);
@@ -161,11 +195,20 @@ void wrap_init()
   Glib::wrap_register(g_filename_completer_get_type(), &Gio::FilenameCompleter_Class::wrap_new);
   Glib::wrap_register(g_filter_input_stream_get_type(), &Gio::FilterInputStream_Class::wrap_new);
   Glib::wrap_register(g_filter_output_stream_get_type(), &Gio::FilterOutputStream_Class::wrap_new);
+  Glib::wrap_register(g_io_stream_get_type(), &Gio::IOStream_Class::wrap_new);
+  Glib::wrap_register(g_inet_address_get_type(), &Gio::InetAddress_Class::wrap_new);
+  Glib::wrap_register(g_inet_socket_address_get_type(), &Gio::InetSocketAddress_Class::wrap_new);
   Glib::wrap_register(g_input_stream_get_type(), &Gio::InputStream_Class::wrap_new);
   Glib::wrap_register(g_memory_input_stream_get_type(), &Gio::MemoryInputStream_Class::wrap_new);
   Glib::wrap_register(g_memory_output_stream_get_type(), &Gio::MemoryOutputStream_Class::wrap_new);
   Glib::wrap_register(g_mount_operation_get_type(), &Gio::MountOperation_Class::wrap_new);
+  Glib::wrap_register(g_network_address_get_type(), &Gio::NetworkAddress_Class::wrap_new);
+  Glib::wrap_register(g_network_service_get_type(), &Gio::NetworkService_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
+  Glib::wrap_register(g_resolver_get_type(), &Gio::Resolver_Class::wrap_new);
+  Glib::wrap_register(g_socket_get_type(), &Gio::Socket_Class::wrap_new);
+  Glib::wrap_register(g_socket_address_get_type(), &Gio::SocketAddress_Class::wrap_new);
+  Glib::wrap_register(g_socket_address_enumerator_get_type(), &Gio::SocketAddressEnumerator_Class::wrap_new);
   Glib::wrap_register(g_themed_icon_get_type(), &Gio::ThemedIcon_Class::wrap_new);
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_input_stream_get_type(), &Gio::UnixInputStream_Class::wrap_new);
@@ -188,6 +231,7 @@ void wrap_init()
   Gio::Emblem::get_type();
   Gio::EmblemedIcon::get_type();
   Gio::FileEnumerator::get_type();
+  Gio::FileIOStream::get_type();
   Gio::FileIcon::get_type();
   Gio::FileInfo::get_type();
   Gio::FileInputStream::get_type();
@@ -196,11 +240,20 @@ void wrap_init()
   Gio::FilenameCompleter::get_type();
   Gio::FilterInputStream::get_type();
   Gio::FilterOutputStream::get_type();
+  Gio::IOStream::get_type();
+  Gio::InetAddress::get_type();
+  Gio::InetSocketAddress::get_type();
   Gio::InputStream::get_type();
   Gio::MemoryInputStream::get_type();
   Gio::MemoryOutputStream::get_type();
   Gio::MountOperation::get_type();
+  Gio::NetworkAddress::get_type();
+  Gio::NetworkService::get_type();
   Gio::OutputStream::get_type();
+  Gio::Resolver::get_type();
+  Gio::Socket::get_type();
+  Gio::SocketAddress::get_type();
+  Gio::SocketAddressEnumerator::get_type();
   Gio::ThemedIcon::get_type();
 #ifndef G_OS_WIN32
   Gio::UnixInputStream::get_type();
